@@ -1,9 +1,10 @@
 import random
 import json
+import pkgutil
 
 def happy_hacktoberfest():
-    with open('data/contributors.json') as f:
-        data = json.load(f)
+    test = pkgutil.get_data(__name__, "data/contributors.json")
+    data = json.loads(test)
     pick = random.choice(data)
     sentence = "{} wishes you {}".format(pick["author"], pick["wish"])
     return sentence
